/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

[scriptable, builtinclass, uuid(7ee758eb-9353-4ade-8715-9953ea512ee2)]
interface nsIDOMMozContactChangeEvent : nsIDOMEvent
{
  readonly attribute DOMString contactID;
  readonly attribute DOMString reason;

  [noscript] void initMozContactChangeEvent(in DOMString aType,
                                            in boolean aCanBubble,
                                            in boolean aCancelable,
                                            in DOMString aContactID,
                                            in DOMString aReason);
};

dictionary MozContactChangeEventInit : EventInit
{
  DOMString contactID;
  DOMString reason;
};
