/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

[scriptable, uuid(ff69a292-c74d-4ef5-9d0f-86112fff2d5b)]
interface nsIDOMPlugin : nsISupports
{
  readonly attribute DOMString        description;
  readonly attribute DOMString        filename;
  readonly attribute DOMString        version;
  readonly attribute DOMString        name;

  readonly attribute unsigned long    length;
  nsIDOMMimeType            item(in unsigned long index);
  nsIDOMMimeType            namedItem(in DOMString name);
};
