/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMHTMLElement.idl"

/**
 * The nsIDOMHTMLImageElement interface is the interface to a [X]HTML
 * img element.
 *
 * This interface is trying to follow the DOM Level 2 HTML specification:
 * http://www.w3.org/TR/DOM-Level-2-HTML/
 *
 * with changes from the work-in-progress WHATWG HTML specification:
 * http://www.whatwg.org/specs/web-apps/current-work/
 */

[scriptable, uuid(0e2ffdcb-b881-436b-a450-4790f47b60fe)]
interface nsIDOMHTMLImageElement : nsIDOMHTMLElement
{
           attribute DOMString        alt;
           attribute DOMString        src;
           attribute DOMString        crossOrigin;
           attribute DOMString        useMap;
           attribute boolean          isMap;
           attribute unsigned long    width;
           attribute unsigned long    height;
  readonly attribute unsigned long    naturalWidth;
  readonly attribute unsigned long    naturalHeight;
  readonly attribute boolean          complete;


           attribute DOMString        name;
           attribute DOMString        align;
           attribute DOMString        border;
           attribute long             hspace;       
           attribute DOMString        longDesc;
           attribute long             vspace;
           attribute DOMString        lowsrc;

  // These attributes are offsets from the closest view (to mimic
  // NS4's "offset-from-layer" behavior).
  readonly attribute long             x;
  readonly attribute long             y;
};
