/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * Interface for a client side storage item. See
 * http://www.whatwg.org/specs/web-apps/current-work/#scs-client-side
 * for more information.
 *
 * A respresentation of a storage object item.
 */

[scriptable, uuid(0CC37C78-4C5F-48E1-ADFC-7480B8FE9DC4)]
interface nsIDOMStorageItem : nsISupports
{
  /**
   * Indicates whether a key is available only in a secure context.
   */
  attribute boolean secure;

  /**
   * The value associated with the item.
   */
  attribute DOMString value;
};
