/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMEventListener;

[scriptable, uuid(a0eb16f3-5fa2-4cbd-bf7a-4ce7704b13ea)]
interface nsIDOMMozConnection : nsISupports
{
  readonly attribute double  bandwidth;
  readonly attribute boolean metered;

  [implicit_jscontext] attribute jsval onchange;
};
