/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, uuid(0d0a6b62-d4a9-402e-a197-6bc6e358fec9)]
interface nsITransportSecurityInfo : nsISupports {
    readonly attribute unsigned long    securityState;
    readonly attribute wstring          shortSecurityDescription;
    readonly attribute wstring          errorMessage;
};

