/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMWindow;

/**
 * This interface allows creating various prompts that have a specific parent.
 */
[scriptable, uuid(2532b748-75db-4732-9173-78d3bf34f694)]
interface nsIPromptFactory : nsISupports
{
  /**
   * Returns an object implementing the specified interface that creates
   * prompts parented to aParent.
   */
  void getPrompt(in nsIDOMWindow aParent, in nsIIDRef iid,
                 [iid_is(iid),retval] out nsQIResult result);
};

