/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"
interface nsIDOMDesktopNotificationCenter;

/**
 * Property that extends the navigator object.
 */
[scriptable, uuid(EC2E6E4F-2F65-439C-B6C6-27E89B03B348)]
interface nsIDOMNavigatorDesktopNotification : nsISupports
{
  readonly attribute nsIDOMDesktopNotificationCenter mozNotification;
};
